stickNAUTA
==========

This is a simple managing interface for ETECSA Nauta with the minimal requirements.

DONE
----
  + Session account status, credit and last three connections.
  + Session login.
  + Session remaining time.
  + Session logout.
  + Session is context friendly.
  + Session data can be saved/load to/from memory or file to save/recover the session.
  + Portal CAPTCHA request and submit.
  + Portal account recharge.
  + Portal change account/email password.
  + Portal transfer balance.
  + Portal account data.
  + Portal connection details with all session historial.
  + Portal recharge details with all recharge historial.
  + Portal transfer details with all transfer historial.
  + Portal data can be saved/load to/from memory or file to save/recover the session.

TODO
----
  - ?

__Please submit all suggestion or issues.__

